@@ -18,6 +18,8 @@ sub new {
     my $self = $class->SUPER::new(%args);
     $self->{_interval}    = $interval;
     $self->{_last_req_at} = undef;
+    $self->agent($args{user_agent}) if exists $args{user_agent};
+    $self->add_header('Accept-Encoding' => 'identity') if DEBUG;
     return $self;
 }
 
@@ -65,6 +67,9 @@ sub request_like_xhr {
     my $req = HTTP::Request->new($method, $url, [
         'Content-Type'     => 'application/json',
         'Content-Length'   => length $content,
+        'Accept'           => 'application/json,text/javascript',
+        'Accept-Language'  => 'en-US',
+        'Origin'           => 'https://connpass.com',
         'X-CSRFToken'      => $self->_csrf_token(),
         'X-Requested-With' => 'XMLHttpRequest',
     ], $content);
